/*
*  Rubrica
*  file: interface.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#include "modulo.h"
#include "rubrica.h"
#include "dialoghi.h"


GtkWidget *bNuovo;
GtkWidget *bApri;
GtkWidget *bSalva;
GtkWidget *bAggiungi;
GtkWidget *bElimina;
GtkWidget *bModifica;
GtkWidget *bPrima;
GtkWidget *bUltima;
GtkWidget *bCerca;
GtkWidget *bEsci;
GtkWidget *bPrecedente;
GtkWidget *bSuccessivo;

/* -----   elementi relativi a vista  -----  */
GtkWidget *label_nomefile;
GtkWidget *clist_schede;
GtkWidget *clist_dati;
GtkWidget *progressbar;
gchar *titolo;
/*  ---------------------------------------  */

GtkWidget *href1;
GtkWidget *href2;
GtkWidget *href_box;
GtkWidget *popup;  /* menu popup */


static GnomeUIInfo file1_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_NEW_ITEM (N_("_New File"), NULL, on_new_file1_activate, NULL),
  GNOMEUIINFO_MENU_OPEN_ITEM (on_open1_activate, NULL),
  GNOMEUIINFO_MENU_SAVE_ITEM (on_save1_activate, NULL),
  GNOMEUIINFO_MENU_SAVE_AS_ITEM (on_save_as1_activate, NULL),
  GNOMEUIINFO_SEPARATOR,
  {
   /* importa */    
    GNOME_APP_UI_ITEM, N_("_Import"),
    NULL,
    on_import_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    GDK_i, GDK_MOD1_MASK, NULL
  },
  {
   /* esporta */    
    GNOME_APP_UI_ITEM, N_("_Export"),
    NULL,
    on_export_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    GDK_e, GDK_MOD1_MASK, NULL
  },
  GNOMEUIINFO_SEPARATOR,
  GNOMEUIINFO_MENU_EXIT_ITEM (on_exit1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo edit1_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_UNDO_ITEM (on_undo_activate, NULL),
  GNOMEUIINFO_MENU_REDO_ITEM (on_redo_activate, NULL),
  GNOMEUIINFO_SEPARATOR,
  GNOMEUIINFO_MENU_CUT_ITEM (on_cut1_activate, NULL),
  GNOMEUIINFO_MENU_COPY_ITEM (on_copy1_activate, NULL),
  GNOMEUIINFO_MENU_PASTE_ITEM (on_paste1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo crescente1_uiinfo[] =
{
  {
/*
    GNOME_APP_UI_ITEM, N_("_Crescente"),
*/
    GNOME_APP_UI_ITEM, N_("_Increasing"),
    NULL,
    on_crescente1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    GDK_c, GDK_MOD1_MASK, NULL
  },
  {
/*
    GNOME_APP_UI_ITEM, N_("D_ecrescente"),
*/
    GNOME_APP_UI_ITEM, N_("D_ecreasing"),
    NULL,
    on_decrescente1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    GDK_e, GDK_MOD1_MASK, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo view1_menu_uiinfo[] =
{
  {
/*
    GNOME_APP_UI_ITEM, N_("_Alfabetica"),
    N_("Mostra le schede in ordine alfabetico"),
*/
    GNOME_APP_UI_ITEM, N_("_Alphabetic"),
    N_("Show the cards in alphabetic order"),
    on_alfabetica1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
/*
  {
    GNOME_APP_UI_ITEM, N_("_Dimensione"),
    N_("Mostra le schede in base alla loro dimensione"),
    on_dimensione1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
*/
  {
/*
    GNOME_APP_UI_ITEM, N_("Da_ta"),
    N_("Mostra le schede in ordine cronologico"),
*/
    GNOME_APP_UI_ITEM, N_("Da_te"),
    N_("Show cards by date"),
    on_data1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
  GNOMEUIINFO_SEPARATOR,
  {
    GNOME_APP_UI_RADIOITEMS, NULL, NULL, crescente1_uiinfo,
    NULL, NULL, 0, NULL, 0, 0, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo settings1_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_PREFERENCES_ITEM (on_preferences1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo help1_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_ABOUT_ITEM (on_about1_activate, NULL),
  {
/*
    GNOME_APP_UI_ITEM, N_("La _Calabria"),
    N_("Visitate la Calabria"),
*/
    GNOME_APP_UI_ITEM, N_("_Calabria"),
    N_("Visit Calabria"),
    on_calabria1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
    0, 0, NULL
  },
  {
/*
    GNOME_APP_UI_ITEM, N_("_Dedicato a..."),
    N_("Questo programma  dedicato a..."),
*/
    GNOME_APP_UI_ITEM, N_("_Dedicated to..."),
    N_("This program is dedicated to..."),
    on_dedicato_a1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
    0, 0, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo menubar1_uiinfo[] =
{
  GNOMEUIINFO_MENU_FILE_TREE (file1_menu_uiinfo),
  GNOMEUIINFO_MENU_EDIT_TREE (edit1_menu_uiinfo),
  GNOMEUIINFO_MENU_VIEW_TREE (view1_menu_uiinfo),
  GNOMEUIINFO_MENU_SETTINGS_TREE (settings1_menu_uiinfo),
  GNOMEUIINFO_MENU_HELP_TREE (help1_menu_uiinfo),
  GNOMEUIINFO_END
};


static GnomeUIInfo popmenu[] =
{
  GNOMEUIINFO_MENU_CUT_ITEM (on_pop_cut_activate, NULL),
  GNOMEUIINFO_MENU_COPY_ITEM (on_pop_copy_activate, NULL),
  GNOMEUIINFO_MENU_PASTE_ITEM (on_pop_paste_activate, NULL),
  GNOMEUIINFO_SEPARATOR,
  {
/*
    GNOME_APP_UI_ITEM, N_("_Modifica"),
*/
    GNOME_APP_UI_ITEM, N_("_Modify"),
    NULL,
    on_pop_modifica_activate, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CONVERT,
    0, 0, NULL
  },
  GNOMEUIINFO_END
};


GtkWidget*
create_app ()
{
  GtkWidget *app;
  GtkWidget *dock1;
  GtkWidget *toolbar1;
  GtkWidget *tmp_toolbar_icon;

  GtkWidget *table1;
  GtkWidget *vseparator1;
  GtkWidget *label10;
  GtkWidget *label8;
  GtkWidget *frame_dati;
  GtkWidget *scrolledwindow4;
  GtkWidget *label26;
  GtkWidget *label27;
  GtkWidget *label28;
  GtkWidget *frame3;
  GtkWidget *hbox1;
/*  GtkWidget *label11; */
  gchar *pixmap1_filename;
  GtkWidget *pixmap1;
  gchar *pixmaprub_filename;
  GtkWidget *pixmap_rub;
  GtkWidget *hbuttonbox1;
  GtkWidget *frame_schede;
  GtkWidget *scrolledwindow5;
  GtkWidget *label29;
  GtkWidget *label30;
  GtkWidget *label31;
  GtkWidget *label32;
  GtkWidget *appbar1;
  GtkTooltips *tooltips;

  g_print("\nRubrica: begin interface creation\n");

  tooltips = gtk_tooltips_new ();
  titolo = _("Rubrica             ");

  g_print("\nRubrica: begin interface creation -- app");
  app = gnome_app_new ("Rubrica", titolo);
  gtk_widget_set_name (app, "app");
  gtk_window_set_default_size(GTK_WINDOW(app), 700,400);
  gtk_object_set_data (GTK_OBJECT (app), "app", app);
  gtk_container_set_border_width (GTK_CONTAINER (app), 4);
  gtk_window_set_position (GTK_WINDOW (app), GTK_WIN_POS_CENTER);
  gtk_window_set_policy (GTK_WINDOW (app), TRUE, TRUE, TRUE);

  dock1 = GNOME_APP (app)->dock;
  gtk_widget_set_name (dock1, "dock1");
  gtk_widget_ref (dock1);
  gtk_object_set_data_full (GTK_OBJECT (app), "dock1", dock1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dock1);
  g_print("\nRubrica: begin interface creation -- app done\n");

  g_print("\nRubrica: begin interface creation -- menu");
  gnome_app_create_menus (GNOME_APP (app), menubar1_uiinfo);

  /*************************
         creazione dei menu
  ************************/
  g_print("\nRubrica: begin interface creation -- menubar");
  
  /* File */  
  gtk_widget_set_name (menubar1_uiinfo[0].widget, "file1");
  gtk_widget_ref (menubar1_uiinfo[0].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "file1",
                            menubar1_uiinfo[0].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (file1_menu_uiinfo[0].widget, "new_file1");
  gtk_widget_ref (file1_menu_uiinfo[0].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "new_file1",
                            file1_menu_uiinfo[0].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (file1_menu_uiinfo[1].widget, "open1");
  gtk_widget_ref (file1_menu_uiinfo[1].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "open1",
                            file1_menu_uiinfo[1].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (file1_menu_uiinfo[2].widget, "save1");
  gtk_widget_ref (file1_menu_uiinfo[2].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "save1",
                            file1_menu_uiinfo[2].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (file1_menu_uiinfo[3].widget, "save_as1");
  gtk_widget_ref (file1_menu_uiinfo[3].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "save_as1",
                            file1_menu_uiinfo[3].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (file1_menu_uiinfo[4].widget, "separator2");
  gtk_widget_ref (file1_menu_uiinfo[4].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "separator2",
                            file1_menu_uiinfo[4].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (file1_menu_uiinfo[5].widget, "import");
  gtk_widget_ref (file1_menu_uiinfo[5].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "import",
                            file1_menu_uiinfo[5].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (file1_menu_uiinfo[6].widget, "export");
  gtk_widget_ref (file1_menu_uiinfo[6].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "export",
                            file1_menu_uiinfo[6].widget,
                            (GtkDestroyNotify) gtk_widget_unref);


  gtk_widget_set_name (file1_menu_uiinfo[7].widget, "separator2");
  gtk_widget_ref (file1_menu_uiinfo[4].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "separator2",
                            file1_menu_uiinfo[4].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (file1_menu_uiinfo[8].widget, "exit1");
  gtk_widget_ref (file1_menu_uiinfo[5].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "exit1",
                            file1_menu_uiinfo[5].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  /* Modifica */
  gtk_widget_set_name (menubar1_uiinfo[1].widget, "edit1");
  gtk_widget_ref (menubar1_uiinfo[1].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "edit1",
                            menubar1_uiinfo[1].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (edit1_menu_uiinfo[0].widget, "undo");
  gtk_widget_ref (edit1_menu_uiinfo[0].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "undo",
                            edit1_menu_uiinfo[0].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (edit1_menu_uiinfo[1].widget, "redo");
  gtk_widget_ref (edit1_menu_uiinfo[1].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "redo",
                            edit1_menu_uiinfo[1].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (edit1_menu_uiinfo[2].widget, "separator2");
  gtk_widget_ref (edit1_menu_uiinfo[2].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "separator2",
                            edit1_menu_uiinfo[2].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (edit1_menu_uiinfo[3].widget, "cut1");
  gtk_widget_ref (edit1_menu_uiinfo[3].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "cut1",
                            edit1_menu_uiinfo[3].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (edit1_menu_uiinfo[4].widget, "copy1");
  gtk_widget_ref (edit1_menu_uiinfo[4].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "copy1",
                            edit1_menu_uiinfo[4].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (edit1_menu_uiinfo[5].widget, "paste1");
  gtk_widget_ref (edit1_menu_uiinfo[5].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "paste1",
                            edit1_menu_uiinfo[5].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  /* Vista */ 
  gtk_widget_set_name (menubar1_uiinfo[2].widget, "view1");
  gtk_widget_ref (menubar1_uiinfo[2].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "view1",
                            menubar1_uiinfo[2].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (view1_menu_uiinfo[0].widget, "alfabetica1");
  gtk_widget_ref (view1_menu_uiinfo[0].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "alfabetica1",
                            view1_menu_uiinfo[0].widget,
                            (GtkDestroyNotify) gtk_widget_unref);
/*
  gtk_widget_set_name (view1_menu_uiinfo[1].widget, "dimensione1");
  gtk_widget_ref (view1_menu_uiinfo[1].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "dimensione1",
                            view1_menu_uiinfo[1].widget,
                            (GtkDestroyNotify) gtk_widget_unref);
*/
  gtk_widget_set_name (view1_menu_uiinfo[2].widget, "data1");
  gtk_widget_ref (view1_menu_uiinfo[2].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "data1",
                            view1_menu_uiinfo[2].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

/*
  gtk_widget_set_name (view1_menu_uiinfo[3].widget, "separator2");
  gtk_widget_ref (view1_menu_uiinfo[3].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "separator2",
                            view1_menu_uiinfo[3].widget,
                            (GtkDestroyNotify) gtk_widget_unref);
*/

  gtk_widget_set_name (crescente1_uiinfo[0].widget, "crescente1");
  gtk_widget_ref (crescente1_uiinfo[0].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "crescente1",
                            crescente1_uiinfo[0].widget,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (crescente1_uiinfo[0].widget),
				  TRUE);

  gtk_widget_set_name (crescente1_uiinfo[1].widget, "decrescente1");
  gtk_widget_ref (crescente1_uiinfo[1].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "decrescente1",
                            crescente1_uiinfo[1].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (menubar1_uiinfo[3].widget, "settings1");
  gtk_widget_ref (menubar1_uiinfo[3].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "settings1",
                            menubar1_uiinfo[3].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (settings1_menu_uiinfo[0].widget, "preferences1");
  gtk_widget_ref (settings1_menu_uiinfo[0].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "preferences1",
                            settings1_menu_uiinfo[0].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (menubar1_uiinfo[4].widget, "help1");
  gtk_widget_ref (menubar1_uiinfo[4].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "help1",
                            menubar1_uiinfo[4].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (help1_menu_uiinfo[0].widget, "about1");
  gtk_widget_ref (help1_menu_uiinfo[0].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "about1",
                            help1_menu_uiinfo[0].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (help1_menu_uiinfo[1].widget, "calabria1");
  gtk_widget_ref (help1_menu_uiinfo[1].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "calabria1",
                            help1_menu_uiinfo[1].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_set_name (help1_menu_uiinfo[2].widget, "dedicato_a1");
  gtk_widget_ref (help1_menu_uiinfo[2].widget);
  gtk_object_set_data_full (GTK_OBJECT (app), "dedicato_a1",
                            help1_menu_uiinfo[2].widget,
                            (GtkDestroyNotify) gtk_widget_unref);

  g_print("\nRubrica: begin interface creation -- menubar done\n");
  g_print("\nRubrica: begin interface creation -- toolbar");

  /*                                                                       */
  /*  ***************** creazione della toolbar *************************  */
  /*                                                                       */

  toolbar1 = gtk_toolbar_new (GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_BOTH);
  gtk_widget_set_name (toolbar1, "toolbar1");
  gtk_widget_ref (toolbar1);
  gtk_object_set_data_full (GTK_OBJECT (app), "toolbar1", toolbar1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (toolbar1);
  gnome_app_add_toolbar (GNOME_APP (app), GTK_TOOLBAR (toolbar1), "toolbar1",
                                GNOME_DOCK_ITEM_BEH_EXCLUSIVE,
                                GNOME_DOCK_TOP, 1, 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (toolbar1), 1);
  gtk_toolbar_set_space_size (GTK_TOOLBAR (toolbar1), 20);
  gtk_toolbar_set_space_style (GTK_TOOLBAR (toolbar1), GTK_TOOLBAR_SPACE_LINE);
  gtk_toolbar_set_button_relief (GTK_TOOLBAR (toolbar1), GTK_RELIEF_NONE);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_NEW);
  bNuovo = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("New"),
/*
                                _("Crea una nuova rubrica"), NULL,
*/
                                _("Make a new address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bNuovo, "bNuovo");
  gtk_widget_ref (bNuovo);
  gtk_object_set_data_full (GTK_OBJECT (app), "bNuovo", bNuovo,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bNuovo);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_OPEN);
  bApri = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Open"),
/*
                                _("Apri una rubrica"), NULL,
*/
                                _("Open an existing address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bApri, "bApri");
  gtk_widget_ref (bApri);
  gtk_object_set_data_full (GTK_OBJECT (app), "bApri", bApri,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bApri);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_SAVE);
  bSalva = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Save"),
/*
                                _("Salva la rubrica corrente"), NULL,
*/
                                _("Save current address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bSalva, "bSalva");
  gtk_widget_ref (bSalva);
  gtk_object_set_data_full (GTK_OBJECT (app), "bSalva", bSalva,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bSalva);

  gtk_toolbar_append_space (GTK_TOOLBAR (toolbar1));

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_ADD);
  bAggiungi = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Add"),
/*
                                _("Aggiungi una scheda alla rubrica"), NULL,
*/
                                _("Add a card to the address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bAggiungi, "bAggiungi");
  gtk_widget_ref (bAggiungi);
  gtk_object_set_data_full (GTK_OBJECT (app), "bAggiungi", bAggiungi,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bAggiungi);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_REMOVE);
  bElimina = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Delete"),
/*
                                _("Elimina una scheda dalla rubrica"), NULL,
*/
                                _("Delete a card from address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bElimina, "bElimina");
  gtk_widget_ref (bElimina);
  gtk_object_set_data_full (GTK_OBJECT (app), "bElimina", bElimina,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bElimina);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_CONVERT);
  bModifica = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Modify"),
/*
                                _("Modifica la scheda selezionata"), NULL,
*/
                                _("Modify the selected card"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bModifica, "bModifica");
  gtk_widget_ref (bModifica);
  gtk_object_set_data_full (GTK_OBJECT (app), "bModifica", bModifica,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bModifica);

  gtk_toolbar_append_space (GTK_TOOLBAR (toolbar1));

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_TOP);
  bPrima = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("First"),
/*
                                _("Visualizza la prima scheda della rubrica"), NULL,
*/
                                _("Show first card in the address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bPrima, "bPrima");
  gtk_widget_ref (bPrima);
  gtk_object_set_data_full (GTK_OBJECT (app), "bPrima", bPrima,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bPrima);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_BOTTOM);
  bUltima = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Last"),
/*
                                _("Visualizza l'ultima scheda della rubrica"), NULL,
*/
                                _("Show last card in the address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bUltima, "bUltima");
  gtk_widget_ref (bUltima);
  gtk_object_set_data_full (GTK_OBJECT (app), "bUltima", bUltima,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bUltima);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_SEARCH);
  bCerca = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Search"),
/*
                                _("Cerca la scheda ..."), NULL,
*/
                                _("Search card ..."), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bCerca, "bCerca");
  gtk_widget_ref (bCerca);
  gtk_object_set_data_full (GTK_OBJECT (app), "bCerca", bCerca,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bCerca);

  gtk_toolbar_append_space (GTK_TOOLBAR (toolbar1));

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_EXIT);
  bEsci = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Exit"),
/*
                                _("Esci dal programma"), NULL,
*/
                                _("Exit program"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_widget_set_name (bEsci, "bEsci");
  gtk_widget_ref (bEsci);
  gtk_object_set_data_full (GTK_OBJECT (app), "bEsci", bEsci,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bEsci);
  g_print("\nRubrica: begin interface creation -- toolbar done");
  g_print("\nRubrica: begin interface creation -- menu done\n");
  

  /* ******************************************************************* */

  /* ***********************************************
     inizia la costruzione della tabella contenente
     le clist e i dati statistici
     ***********************************************
  */	
  g_print("\nRubrica: begin interface creation -- table");
  table1 = gtk_table_new (6, 6, FALSE);
  gtk_widget_set_name (table1, "table1");
  gtk_widget_ref (table1);
  gtk_object_set_data_full (GTK_OBJECT (app), "table1", table1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table1);
  g_print("\nRubrica: begin interface creation -- table done\n");

  gnome_app_set_contents (GNOME_APP (app), table1);
  gtk_container_set_border_width (GTK_CONTAINER (table1), 5);
  gtk_table_set_row_spacings (GTK_TABLE (table1), 4);
  gtk_table_set_col_spacings (GTK_TABLE (table1), 4);

  label_nomefile = gtk_label_new ("");
  gtk_widget_set_name (label_nomefile, "label_nomefile");
  gtk_widget_ref (label_nomefile);
  gtk_object_set_data_full (GTK_OBJECT (app), "label_nomefile", label_nomefile,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_nomefile);
  gtk_table_attach (GTK_TABLE (table1), label_nomefile, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_nomefile), 0.0, 0.5);

  vseparator1 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator1, "vseparator1");
  gtk_widget_ref (vseparator1);
  gtk_object_set_data_full (GTK_OBJECT (app), "vseparator1", vseparator1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator1);
  gtk_table_attach (GTK_TABLE (table1), vseparator1, 2, 3, 0, 6,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

/*
  label10 = gtk_label_new (_("Indirizzi inseriti: "));
*/
  label10 = gtk_label_new (_("Inserted address: "));
  gtk_widget_set_name (label10, "label10");
  gtk_widget_ref (label10);
  gtk_object_set_data_full (GTK_OBJECT (app), "label10", label10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label10);
  gtk_table_attach (GTK_TABLE (table1), label10, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_SHRINK),
                    (GtkAttachOptions) (GTK_EXPAND), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label10), GTK_JUSTIFY_RIGHT);
  gtk_label_set_line_wrap (GTK_LABEL (label10), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label10), 1, 0.5);

  label8 = gtk_label_new (_("File: "));
  gtk_widget_set_name (label8, "label8");
  gtk_widget_ref (label8);
  gtk_object_set_data_full (GTK_OBJECT (app), "label8", label8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8);
  gtk_table_attach (GTK_TABLE (table1), label8, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_SHRINK),
                    (GtkAttachOptions) (GTK_EXPAND), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label8), GTK_JUSTIFY_RIGHT);
  gtk_label_set_line_wrap (GTK_LABEL (label8), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label8), 1, 0.5);

/*
  frame_dati = gtk_frame_new (_(" Dati "));
*/
  g_print("\nRubrica: begin interface creation -- frame");

  frame_dati = gtk_frame_new (_(" Data "));
  gtk_widget_set_name (frame_dati, "frame_dati");
  gtk_widget_ref (frame_dati);
  gtk_object_set_data_full (GTK_OBJECT (app), "frame_dati", frame_dati,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_dati);
  g_print("\nRubrica: begin interface creation -- frame done\n");
  gtk_table_attach (GTK_TABLE (table1), frame_dati, 3, 6, 0, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);

  /*    scrolled window per la finestra dei dati
  */
  g_print("\nRubrica: begin interface creation -- scrolled window");

  scrolledwindow4 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow4, "scrolledwindow4");
  gtk_widget_ref (scrolledwindow4);
  gtk_object_set_data_full (GTK_OBJECT (app), "scrolledwindow4", scrolledwindow4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow4);
  g_print("\nRubrica: begin interface creation -- scrolled window done\n");

  gtk_container_add (GTK_CONTAINER (frame_dati), scrolledwindow4);
/*
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow4),
				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
*/


  /*  
         *****************  CLIST  DATI  ****************** 
  */
  g_print("\nRubrica: begin interface creation -- clist dati");

  clist_dati = gtk_clist_new (3);
  gtk_widget_set_name (clist_dati, "clist_dati");
  gtk_widget_ref (clist_dati);
  gtk_object_set_data_full (GTK_OBJECT (app), "clist_dati", clist_dati,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_dati);
  gtk_container_add (GTK_CONTAINER (scrolledwindow4), clist_dati);
  gtk_clist_set_column_width (GTK_CLIST (clist_dati), 0, 15);
  gtk_clist_set_column_width (GTK_CLIST (clist_dati), 1, 130);
  gtk_clist_set_column_width (GTK_CLIST (clist_dati), 2, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_dati));
  g_print("\nRubrica: begin interface creation -- clist dati done\n");

  label26 = gtk_label_new ("");
  gtk_widget_set_name (label26, "label26");
  gtk_widget_ref (label26);
  gtk_object_set_data_full (GTK_OBJECT (app), "label26", label26,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label26);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dati), 0, label26);

  label27 = gtk_label_new ("");
  gtk_widget_set_name (label27, "label27");
  gtk_widget_ref (label27);
  gtk_object_set_data_full (GTK_OBJECT (app), "label27", label27,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label27);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dati), 1, label27);

  label28 = gtk_label_new ("");
  gtk_widget_set_name (label28, "label28");
  gtk_widget_ref (label28);
  gtk_object_set_data_full (GTK_OBJECT (app), "label28", label28,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label28);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dati), 2, label28);

  g_print("\nRubrica: begin interface creation -- progress bar");
  progressbar = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar, "progressbar");
  gtk_widget_ref (progressbar);
  gtk_object_set_data_full (GTK_OBJECT (app), "progressbar", progressbar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar);
  g_print("\nRubrica: begin interface creation -- progress bar done\n");

  gtk_table_attach (GTK_TABLE (table1), progressbar, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_SHRINK), 0, 0);
  gtk_progress_configure (GTK_PROGRESS (progressbar), 0, 0, 1000);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar), _("%V %"));

  frame3 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame3, "frame3");
  gtk_widget_ref (frame3);
  gtk_object_set_data_full (GTK_OBJECT (app), "frame3", frame3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame3);
  gtk_table_attach (GTK_TABLE (table1), frame3, 0, 2, 5, 6,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame3), 5);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox1, "hbox1");
  gtk_widget_ref (hbox1);
  gtk_object_set_data_full (GTK_OBJECT (app), "hbox1", hbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox1);
  gtk_container_add (GTK_CONTAINER (frame3), hbox1);

  /*      pixmap --- rubrica.png --- 
  */
  g_print("\nRubrica: begin interface creation -- pixmap1");

  pixmap_rub = gtk_type_new (gnome_pixmap_get_type ());
  pixmaprub_filename = gnome_pixmap_file ("rubrica/rubrica.jpg");
  if (pixmaprub_filename)
    gnome_pixmap_load_file (GNOME_PIXMAP (pixmap_rub), pixmaprub_filename);
  else
/*
    g_warning (_("Impossibile aprire il file: %s"), "rubrica.jpg");
*/
    g_warning (_("Couldn't find pixmap file: %s"), "rubrica.jpg");
  g_free (pixmaprub_filename);
  gtk_widget_set_name (pixmap_rub, "pixmap_rub");
  gtk_widget_ref (pixmap_rub);
  gtk_object_set_data_full (GTK_OBJECT (app), "pixmap_rub", pixmap_rub,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (pixmap_rub);
  g_print("\nRubrica: begin interface creation -- pixmap1 done\n");

  gtk_box_pack_start (GTK_BOX (hbox1), pixmap_rub, FALSE, FALSE, 0);

  href_box = gtk_vbox_new(FALSE, 0);
  gtk_box_pack_start(GTK_BOX(hbox1), href_box, FALSE, FALSE, 0);
  gtk_widget_show(href_box);

  g_print("\nRubrica: begin interface creation -- href");

  href1 = gnome_href_new ("mailto:nicolafragale@libero.it", 
			  _("<nicolafragale@libero.it>"));
  gtk_widget_set_name (href1, "href1");
  gtk_widget_ref (href1);
  gtk_object_set_data_full (GTK_OBJECT (app), "href1", href1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (href1);
  gtk_box_pack_start (GTK_BOX (href_box), href1, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (href1), 0);

  href2 = gnome_href_new ("http://digilander.iol.it/nfragale", 
			  _("Rubrica home site"));
  gtk_widget_set_name (href2, "href2");
  gtk_widget_ref (href2);
  gtk_object_set_data_full (GTK_OBJECT (app), "href2", href2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (href2);
  g_print("\nRubrica: begin interface creation -- href done\n");

  gtk_box_pack_start (GTK_BOX (href_box), href2, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (href2), 0);

  /*      pixmap --- gnome.png ---
  */
  g_print("\nRubrica: begin interface creation -- pixmap2");
  pixmap1 = gtk_type_new (gnome_pixmap_get_type ());
  pixmap1_filename = gnome_pixmap_file ("rubrica/gnome.png");
  if (pixmap1_filename)
    gnome_pixmap_load_file (GNOME_PIXMAP (pixmap1), pixmap1_filename);
  else
/*
    g_warning (_("Impossibile aprire il file: %s"), "gnome.png");
*/
    g_warning (_("Couldn't find pixmap file: %s"), "gnome.png");
  g_free (pixmap1_filename);
  gtk_widget_set_name (pixmap1, "pixmap1");
  gtk_widget_ref (pixmap1);
  gtk_object_set_data_full (GTK_OBJECT (app), "pixmap1", pixmap1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (pixmap1);
  g_print("\nRubrica: begin interface creation -- pixmap2 done\n");
  gtk_box_pack_start (GTK_BOX (hbox1), pixmap1, TRUE, TRUE, 0);

  g_print("\nRubrica: begin interface creation -- buttons");
  hbuttonbox1 = gtk_hbutton_box_new ();
  gtk_widget_set_name (hbuttonbox1, "hbuttonbox1");
  gtk_widget_ref (hbuttonbox1);
  gtk_object_set_data_full (GTK_OBJECT (app), "hbuttonbox1", hbuttonbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbuttonbox1);
  gtk_table_attach (GTK_TABLE (table1), hbuttonbox1, 0, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1), GTK_BUTTONBOX_SPREAD);
  gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbuttonbox1), 10);
  gtk_button_box_set_child_ipadding (GTK_BUTTON_BOX (hbuttonbox1), 0, -1);

  bPrecedente = gnome_stock_button (GNOME_STOCK_BUTTON_PREV);
  gtk_widget_set_name (bPrecedente, "bPrecedente");
  gtk_widget_ref (bPrecedente);
  gtk_object_set_data_full (GTK_OBJECT (app), "bPrecedente", bPrecedente,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bPrecedente);
  gtk_container_add (GTK_CONTAINER (hbuttonbox1), bPrecedente);
  GTK_WIDGET_SET_FLAGS (bPrecedente, GTK_CAN_DEFAULT);
/*
  gtk_tooltips_set_tip (tooltips, bPrecedente, _("Mostra la scheda precedente"),NULL);
*/
  gtk_tooltips_set_tip (tooltips, bPrecedente, _("Show previous card"),NULL);

  bSuccessivo = gnome_stock_button (GNOME_STOCK_BUTTON_NEXT);
  gtk_widget_set_name (bSuccessivo, "bSuccessivo");
  gtk_widget_ref (bSuccessivo);
  gtk_object_set_data_full (GTK_OBJECT (app), "bSuccessivo", bSuccessivo,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bSuccessivo);
  gtk_container_add (GTK_CONTAINER (hbuttonbox1), bSuccessivo);
  GTK_WIDGET_SET_FLAGS (bSuccessivo, GTK_CAN_DEFAULT);
/*
  gtk_tooltips_set_tip (tooltips, bSuccessivo, _("Mostra la scheda successiva"), 
			NULL);
*/
  gtk_tooltips_set_tip (tooltips, bSuccessivo, _("Show next card"), NULL);
  g_print("\nRubrica: begin interface creation -- buttons done\n");

/*
  frame_schede = gtk_frame_new (_(" Schede "));
*/
  g_print("\nRubrica: begin interface creation -- frame");
  frame_schede = gtk_frame_new (_(" Cards "));
  gtk_widget_set_name (frame_schede, "frame_schede");
  gtk_widget_ref (frame_schede);
  gtk_object_set_data_full (GTK_OBJECT (app), "frame_schede", frame_schede,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_schede);
  gtk_table_attach (GTK_TABLE (table1), frame_schede, 0, 2, 0, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);

  scrolledwindow5 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow5, "scrolledwindow5");
  gtk_widget_ref (scrolledwindow5);
  gtk_object_set_data_full (GTK_OBJECT (app), "scrolledwindow5", scrolledwindow5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow5);
  gtk_container_add (GTK_CONTAINER (frame_schede), scrolledwindow5);

  g_print("\nRubrica: begin interface creation -- frame done\n");
  g_print("\nRubrica: begin interface creation -- clist schede");

  /*
          ********************  CLIST SCHEDE  ********************
  */
  clist_schede = gtk_clist_new (4);
  gtk_widget_set_name (clist_schede, "clist_schede");
  gtk_widget_ref (clist_schede);
  gtk_object_set_data_full (GTK_OBJECT (app), "clist_schede", clist_schede,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_schede);
  gtk_container_add (GTK_CONTAINER (scrolledwindow5), clist_schede);
  gtk_clist_set_column_width (GTK_CLIST (clist_schede), 0, 14);
  gtk_clist_set_column_width (GTK_CLIST (clist_schede), 1, 103);
  gtk_clist_set_column_width (GTK_CLIST (clist_schede), 2, 122);
  gtk_clist_set_column_width (GTK_CLIST (clist_schede), 3, 80);
  gtk_clist_column_title_active(GTK_CLIST (clist_schede), 1);
  gtk_clist_column_title_active(GTK_CLIST (clist_schede), 2);
  gtk_clist_column_title_active(GTK_CLIST (clist_schede), 3);
  gtk_clist_column_titles_show (GTK_CLIST (clist_schede));
  g_print("\nRubrica: begin interface creation -- clist schede done\n");
            
  /*     collego il menu popup alla clist
  */
  popup = gnome_popup_menu_new(popmenu);


  label29 = gtk_label_new ("");
  gtk_widget_set_name (label29, "label29");
  gtk_widget_ref (label29);
  gtk_object_set_data_full (GTK_OBJECT (app), "label29", label29,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label29);
  gtk_clist_set_column_widget (GTK_CLIST (clist_schede), 0, label29);

/*
  label30 = gtk_label_new (_("Scheda"));
*/
  label30 = gtk_label_new (_("Card"));
  gtk_widget_set_name (label30, "label30");
  gtk_widget_ref (label30);
  gtk_object_set_data_full (GTK_OBJECT (app), "label30", label30,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label30);
  gtk_clist_set_column_widget (GTK_CLIST (clist_schede), 1, label30);

/*
  label31 = gtk_label_new (_("Nome"));
*/
  label31 = gtk_label_new (_("Name"));
  gtk_widget_set_name (label31, "label31");
  gtk_widget_ref (label31);
  gtk_object_set_data_full (GTK_OBJECT (app), "label31", label31,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label31);
  gtk_clist_set_column_widget (GTK_CLIST (clist_schede), 2, label31);

/*
  label32 = gtk_label_new (_("Cognome"));
*/
  label32 = gtk_label_new (_("Surname"));
  gtk_widget_set_name (label32, "label32");
  gtk_widget_ref (label32);
  gtk_object_set_data_full (GTK_OBJECT (app), "label32", label32,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label32);
  gtk_clist_set_column_widget (GTK_CLIST (clist_schede), 3, label32);

  appbar1 = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_NEVER);
  gtk_widget_set_name (appbar1, "appbar1");
  gtk_widget_ref (appbar1);
  gtk_object_set_data_full (GTK_OBJECT (app), "appbar1", appbar1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (appbar1);
  g_print("\nRubrica: begin interface creation -- status bar");
  gnome_app_set_statusbar (GNOME_APP (app), appbar1);
  g_print("\nRubrica: begin interface creation -- status bar done\n");

  g_print("\nRubrica: begin interface creation -- menu installation");
  gnome_app_install_menu_hints (GNOME_APP (app), menubar1_uiinfo);
  g_print("\nRubrica: begin interface creation -- menu installation done\n");


  /*    CALLBACK PER LA TOOLBAR
  */
  g_print("\nRubrica: begin interface creation -- callbacks setting");
  
  gtk_signal_connect (GTK_OBJECT (bNuovo), "clicked",
                      GTK_SIGNAL_FUNC (on_bNuovo_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (bApri), "clicked",
                      GTK_SIGNAL_FUNC (on_bApri_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (bSalva), "clicked",
                      GTK_SIGNAL_FUNC (on_bSalva_clicked),
                      NULL);

  gtk_signal_connect (GTK_OBJECT (bAggiungi), "clicked",
                      GTK_SIGNAL_FUNC (on_bAggiungi_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (bElimina), "clicked",
                      GTK_SIGNAL_FUNC (on_bElimina_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (bModifica), "clicked",
                      GTK_SIGNAL_FUNC (on_bModifica_clicked),
                      NULL);

  gtk_signal_connect (GTK_OBJECT (bPrima), "clicked",
                      GTK_SIGNAL_FUNC (on_bPrima_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (bUltima), "clicked",
                      GTK_SIGNAL_FUNC (on_bUltima_clicked),
                      NULL);

  gtk_signal_connect (GTK_OBJECT (bCerca), "clicked",
                      GTK_SIGNAL_FUNC (on_bCerca_clicked),
                      NULL);

  gtk_signal_connect (GTK_OBJECT (bEsci), "clicked",
                      GTK_SIGNAL_FUNC (on_exit_clicked),
                      NULL);

  /*    CALLBACK PER I BOTTONI DELLA FINESTRA
  */  
  gtk_signal_connect (GTK_OBJECT (bPrecedente), "clicked",
                      GTK_SIGNAL_FUNC (on_bPrecedente_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (bSuccessivo), "clicked",
                      GTK_SIGNAL_FUNC (on_bSuccessivo_clicked),
                      NULL);

  /*    CALLBACK PER LE CLIST -- SCHEDE E DATI
  */
  gtk_signal_connect (GTK_OBJECT (clist_schede), "select-row",
                      GTK_SIGNAL_FUNC (on_schede_clist_select_row),
                      NULL);
  gtk_signal_connect(GTK_OBJECT(clist_schede), "button_press_event",
		     GTK_SIGNAL_FUNC(on_schede_clist_button_click),
		     NULL);
  gtk_signal_connect(GTK_OBJECT(clist_schede), "click-column",
		     GTK_SIGNAL_FUNC(on_clicked_column_cb),
		     NULL);

  gtk_signal_connect (GTK_OBJECT (clist_dati), "select-row",
		      GTK_SIGNAL_FUNC (on_dati_clist_select_row),
                      NULL);
  gtk_signal_connect(GTK_OBJECT(clist_dati), "button_press_event",
		     GTK_SIGNAL_FUNC(on_dati_clist_button_click),
		     NULL);
 
  gtk_object_set_data (GTK_OBJECT (app), "tooltips", tooltips);
  g_print("\nRubrica: begin interface creation -- callbacks setting done\n");

  /*inizializzo la struttura vista */
  g_print("\nRubrica: begin interface creation -- init view");
  rubrica_init_vista(label_nomefile, clist_schede, clist_dati, progressbar, titolo);
  g_print("\nRubrica: begin interface creation -- init view done\n");
  g_print("\nRubrica: begin interface creation done");

  return app;
}


GtkWidget *get_bModifica(void)
{
  return GTK_WIDGET(bModifica);
}
